<?php

namespace Litecms\Ourteam\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Ourteam\Models\Ourteam;

class OurteamPolicy
{

    /**
     * Determine if the given user can view the ourteam.
     *
     * @param UserPolicy $user
     * @param Ourteam $ourteam
     *
     * @return bool
     */
    public function view(UserPolicy $user, Ourteam $ourteam)
    {
        if ($user->canDo('ourteam.ourteam.view') && $user->isAdmin()) {
            return true;
        }

        return $ourteam->user_id == user_id() && $ourteam->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ourteam.
     *
     * @param UserPolicy $user
     * @param Ourteam $ourteam
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ourteam.ourteam.create');
    }

    /**
     * Determine if the given user can update the given ourteam.
     *
     * @param UserPolicy $user
     * @param Ourteam $ourteam
     *
     * @return bool
     */
    public function update(UserPolicy $user, Ourteam $ourteam)
    {
        if ($user->canDo('ourteam.ourteam.edit') && $user->isAdmin()) {
            return true;
        }

        return $ourteam->user_id == user_id() && $ourteam->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ourteam.
     *
     * @param UserPolicy $user
     * @param Ourteam $ourteam
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Ourteam $ourteam)
    {
        return $ourteam->user_id == user_id() && $ourteam->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ourteam.
     *
     * @param UserPolicy $user
     * @param Ourteam $ourteam
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Ourteam $ourteam)
    {
        if ($user->canDo('ourteam.ourteam.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ourteam.
     *
     * @param UserPolicy $user
     * @param Ourteam $ourteam
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Ourteam $ourteam)
    {
        if ($user->canDo('ourteam.ourteam.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
